@@ -200,7 +200,10 @@ def iis(ctx, bucket, key, sites='', password=None, profile=None):
         sedge install.iis -b ssl.example.com -k wildcard.pfx `
             --sites www.example.com,site2.example.com
     """
+    import clr
     from .sewer import install_cert_on_windows
+    ref = 'c:/Windows/System32/inetsrv/Microsoft.Web.Administration.dll'
+    clr.AddReference(ref)
     thumbprint = install_cert_on_windows(ctx, bucket, key, profile, password)
     sites = sites.split(',')
     suffix = """
@@ -290,29 +293,50 @@ def winrm(ctx, bucket, key, password=None, profile=None):
       https://docs.rackspace.com/support/how-to/enabling-tls-1.2-on-windows-server/
     """
     from .sewer import install_cert_on_windows
+    import clr
+    from System.Security.Cryptography.X509Certificates import StoreName
+    from System.Security.Cryptography.X509Certificates import StoreLocation
+    from System.Security.Cryptography.X509Certificates import OpenFlags
+    from System.Security.Cryptography.X509Certificates import X509FindType
+    from System.Security.Cryptography.X509Certificates import X509Store
+    from System.Security.AccessControl import FileSystemAccessRule
+    from System.Security.AccessControl import FileSystemRights
+    from System.Security.AccessControl import AccessControlType
+    from Security.Cryptography.X509Certificates import RSACertificateExtensions
+    from System.IO import File
     thumbprint = install_cert_on_windows(
         ctx, bucket, key, profile, password, 'my')
+
+    store = StoreName.My
+    root_store = StoreLocation.LocalMachine
+    store = X509Store(store, root_store)
+    store.Open(OpenFlags.ReadWrite | OpenFlags.OpenExistingOnly)
+    try:
+        certs = store.Find(X509FindType.Thumbprint, thumbprint, False)
+        for cert in certs:
+            filename = None
+            try:
+                filename = cert.PrivateKey.CspKeyContainerInfo.UniqueKeyContainerName
+            except:  # pylint: disable=bare-except
+                pass
+            if not filename:
+                filename = RSACertificateExtensions.GetRSAPrivateKey(cert)
+            root_path = r'c:\programdata\microsoft\crypto\rsa\machinekeys'
+            filename = os.path.join(root_path, filename)
+            if os.path.isfile(filename):
+                rule = FileSystemAccessRule(
+                    'NETWORK SERVICE',
+                    FileSystemRights.Read,
+                    AccessControlType.Allow)
+                print(f'modifying acl on {filename}')
+                acl = File.GetAccessControl(filename)
+                acl.AddAccessRule(rule)
+                File.SetAccessControl(filename, acl)
+    finally:
+        store.Close()
+
     c = (
         rf"""
-        $thumbprint = '{thumbprint}'
-        $cert = Get-Item "cert:/localmachine/my/$($thumbprint)"
-        $filename = $cert.privatekey.cspkeycontainerinfo.uniquekeycontainername
-        $root = 'c:\programdata\microsoft\crypto\rsa\machinekeys'
-        $p = [io.path]::combine($root, $filename)
-        $root = 'c:\programdata\microsoft\crypto\keys'
-        $private_key = [Security.Cryptography.X509Certificates.RSACertificateExtensions]::GetRSAPrivateKey($cert)
-        $q = $private_key.key.UniqueName
-        $q = [io.path]::combine($root, $q)
-        $rule = new-object security.accesscontrol.filesystemaccessrule 'NETWORK SERVICE', 'Read', allow
-        foreach ($x in @($p, $q)) {'{'}
-            if ([io.file]::exists($p)) {'{'}
-                echo 'modifying acl'
-                $acl = get-acl -path $x
-                $acl.addaccessrule($rule)
-                echo $x
-                set-acl $x $acl
-            {'}'}
-        {'}'}
         $valueset = @{'{'}
             Hostname = $cert.subject.split('=', 2)[1]
             CertificateThumbprint = $thumbprint
