@@ -3,7 +3,6 @@ from dataclasses import dataclass
 from glob import glob
 import logging
 import os
-import platform
 import posixpath
 import socket
 import sys
@@ -695,14 +694,18 @@ def install_cert_on_linux(
 
 
 def windows_version(ctx):
-    c = r"""
-    $key = 'HKLM:\SOFTWARE\Microsoft\Windows NT\CurrentVersion'
-    $x = Get-ItemProperty $key
-    Write-Host $x.ProductName
-    """
-    print('checking windows version')
-    result = ctx.run(c)
-    version = result.stdout.strip()
+    import clr
+    from Microsoft.Win32 import Registry
+    from Microsoft.Win32 import RegistryHive
+    key = r'SOFTWARE\Microsoft\Windows NT\CurrentVersion'
+    current_version = Registry.LocalMachine.OpenSubKey(key)
+    try:
+        product_name = current_version.GetValue('ProductName')
+        version = product_name.strip()
+    except:  # noqa: E722, pylint: disable=bare-except
+        version = None
+    finally:
+        current_version.Close()
     return version
 
 
@@ -712,71 +715,40 @@ def install_cert_on_windows(
     """
     pull a file from s3 and install in the localmachine/my cert store
     """
-    from cryptography.hazmat.primitives.serialization import pkcs12
-    from cryptography.hazmat.primitives import hashes
+    import clr
     print('getting cert')
     pfx_data = get_pfx(bucket, key, profile)
-    print('getting thumbprint')
-    _, cert, _ = pkcs12.load_key_and_certificates(pfx_data, pfx_password)
-    thumbprint = cert.fingerprint(hashes.SHA1()).hex().upper()
-    f = NamedTemporaryFile(mode='w', delete=False)  # pylint: disable=consider-using-with
-    filename = f.name
-    print(f'importing pfx to cert store from {filename}')
-    with open(filename, 'wb') as f:
-        f.write(pfx_data)
-    cmdlet = ''
-    e = {}
+    password = None
     if pfx_password:
-        password = '-password (ConvertTo-SecureString -f -a $env:SEDGE_PASSWORD)'
-        e['SEDGE_PASSWORD'] = pfx_password
-    else:
-        password = "-password $null"
-    if store:
-        store_arg = rf"-certstorelocation 'cert:\localmachine\{store}'"
-    else:
-        store_arg = r'-certstorelocation cert:\localmachine\my'
-    if platform.release().startswith('2008'):
-        cmdlet = """
-        using namespace System.Security.Cryptography.X509Certificates
-        function Import-PfxCertificate {
-            param([string]$filepath
-              , [string]$root_store = 'localmachine'
-              , [string]$store = 'My'
-              , [security.securestring]$password = $null)
-            Write-Host "importing $filepath"
-            $pfx = new-object X509Certificate2
-            $flags = [X509KeyStorageFlags]::Exportable
-            $flags = $flags -bor [X509KeyStorageFlags]::MachineKeySet
-            $flags = $flags -bor [X509KeyStorageFlags]::PersistKeySet
-            $pfx.import($filepath, $password, $flags)
-            $p = new-object X509Store($store, $root_store)
-            $p.open('MaxAllowed')
-            $exists = $false
-            foreach ($x in $p.certificates) {
-                if ($x.thumbprint -eq $pfx.thumbprint) {
-                    Write-Host 'cert already exists in cert store'
-                    $exists = $true
-                }
-            }
-            if (!($exists)) {
-                $p.add($pfx)
-            }
-            $p.close()
-            return $pfx.thumbprint
-        }
-        """
-        store_arg = ''
-    lines = [
-        cmdlet,
-        f"$t = Import-PfxCertificate -filepath '{filename}' {password} "
-        f"{store_arg}",
-        'Write-Host $t',
-    ]
-    c = '\n'.join(lines)
-    ctx.run(c, env=e)
-    print(f'removing {filename}')
-    os.remove(filename)
-    return thumbprint
+        from System.Net import NetworkCredential
+        password = NetworkCredential('', pfx_password)
+        password = password.Password
+    from System.Security.Cryptography.X509Certificates import X509KeyStorageFlags
+    from System.Security.Cryptography.X509Certificates import X509Certificate2
+    from System.Security.Cryptography.X509Certificates import X509Store
+    from System.Security.Cryptography.X509Certificates import StoreName
+    from System.Security.Cryptography.X509Certificates import StoreLocation
+    from System.Security.Cryptography.X509Certificates import OpenFlags
+    store = store or StoreName.My
+    root_store = StoreLocation.LocalMachine
+    pfx = X509Certificate2()
+    flags = X509KeyStorageFlags.Exportable
+    flags |= X509KeyStorageFlags.MachineKeySet
+    flags |= X509KeyStorageFlags.PersistKeySet
+    pfx.Import(pfx_data, password, flags)
+    p = X509Store(store, root_store)
+    p.Open(OpenFlags.ReadWrite | OpenFlags.OpenExistingOnly)
+    exists = False
+    t = pfx.Thumbprint
+    for x in p.Certificates:
+        if x.Thumbprint == t:
+            print('cert already exists in cert store')
+            exists = True
+            break
+    if not exists:
+        p.Add(pfx)
+    p.Close()
+    return t
 
 
 def is_linux():
